@@ -205,7 +205,6 @@ LSK_USDT = Pair("LSK_USDT", price_precision=4, quantity_precision=2)
 LTC_BTC = Pair("LTC_BTC", price_precision=6, quantity_precision=4)
 LTC_USDC = Pair("LTC_USDC", price_precision=2, quantity_precision=4)
 LTC_USDT = Pair("LTC_USDT", price_precision=2, quantity_precision=5)
-LUNA_USDC = Pair("LUNA_USDC", price_precision=8, quantity_precision=0)
 MANA_BTC = Pair("MANA_BTC", price_precision=9, quantity_precision=1)
 MANA_USDC = Pair("MANA_USDC", price_precision=4, quantity_precision=2)
 MANA_USDT = Pair("MANA_USDT", price_precision=5, quantity_precision=2)
@@ -293,6 +292,7 @@ SKL_USDT = Pair("SKL_USDT", price_precision=5, quantity_precision=2)
 SLP_BTC = Pair("SLP_BTC", price_precision=10, quantity_precision=0)
 SLP_USDC = Pair("SLP_USDC", price_precision=6, quantity_precision=0)
 SLP_USDT = Pair("SLP_USDT", price_precision=5, quantity_precision=1)
+SNT_USDT = Pair("SNT_USDT", price_precision=6, quantity_precision=0)
 SNX_USDT = Pair("SNX_USDT", price_precision=3, quantity_precision=3)
 SOL_BTC = Pair("SOL_BTC", price_precision=7, quantity_precision=3)
 SOL_USDC = Pair("SOL_USDC", price_precision=3, quantity_precision=3)
